function [qt, dim] = CriaFileCoord (v, fname, dimOut, NameEmp, sNameEmp, Class, comInfo, V)
%
% v: Vector com as coordenadas na base dos vectores proprio
% fname: Nome do ficheiro a criar
% dimOut: Quantas dimensões escrever no ficheiro para cada empresa
%
% Exemplo:
%   CriaFileCoord(C, "fname", 250)
%

[qt, dim] = size(v);
if dimOut > dim | dimOut == 0
  dimOut = dim;
end

f1 = fopen(fname,'wt');
for k1 = 1:qt
    if comInfo == 1
        Name = string(NameEmp(k1));
        sName = string(sNameEmp(k1));
        fprintf(f1, '%s | %s | %d | %f | ', Name, sName, Class(k1), V);
    end
    for k2 = 1:dimOut
        fprintf(f1,'%.10f ', v(k1,k2));
    end
    fprintf(f1,'\n');

end
fclose(f1);

end
